@@ -1,8 +1,9 @@
-package Pcore::Ext v0.3.4;
+package Pcore::Ext v0.4.0;
 
 use Pcore -dist, -const;
 use Pcore::Ext::Context;
-use JavaScript::Packer;
+use JavaScript::Packer qw[];
+use JavaScript::Beautifier qw[];
 
 our $SCANNED;
 
@@ -188,7 +189,19 @@ sub SCAN ( $self, $app, $ext, $framework ) {
 
         $class->{js} = $ctx->to_js;
 
-        $js_packer->minify( $ctx->{ctx}->{js}, { compress => 'obfuscate' } ) if !$app->{devel};    # clean
+        if ( $app->{devel} ) {
+            $ctx->{ctx}->{js} = \JavaScript::Beautifier::js_beautify(
+                $ctx->{ctx}->{js}->$*,
+                {   indent_size               => 4,
+                    indent_character          => q[ ],
+                    preserve_newlines         => 1,
+                    space_after_anon_function => 1,
+                }
+            );
+        }
+        else {
+            $js_packer->minify( $ctx->{ctx}->{js}, { compress => 'obfuscate' } );    # clean
+        }
     }
 
     # build ext apps content
@@ -199,25 +212,25 @@ sub SCAN ( $self, $app, $ext, $framework ) {
             # topologically sort deps tree
             my $add_deps = sub ($class_name) {
                 if ( !exists $processed_class{$class_name} ) {
-                    $processed_class{$class_name} = 1;                                             # mark node as "gray"
+                    $processed_class{$class_name} = 1;                               # mark node as "gray"
                 }
                 elsif ( $processed_class{$class_name} == 1 ) {
-                    die q[Cyclic dependency found];                                                # entered to the "gray" node, this is cyclic deps
+                    die q[Cyclic dependency found];                                  # entered to the "gray" node, this is cyclic deps
                 }
                 else {
-                    return;                                                                        # entered to the "black" node
+                    return;                                                          # entered to the "black" node
                 }
 
                 my $class_cfg = $CFG->{class}->{$class_name};
 
                 for my $require ( keys $class_cfg->{requires}->%* ) {
-                    next if !exists $CFG->{class}->{$require};                                     # skip external deps
+                    next if !exists $CFG->{class}->{$require};                       # skip external deps
 
                     __SUB__->($require);
                 }
 
                 # all deps processed
-                $processed_class{$class_name} = 2;                                                 # mark node as "black"
+                $processed_class{$class_name} = 2;                                   # mark node as "black"
 
                 # add content
                 push @app_js, $class_cfg->{js}->$*;
@@ -254,7 +267,7 @@ sub _get_ctx ( $self, $class, $app, $framework ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 19                   | Subroutines::ProhibitExcessComplexity - Subroutine "SCAN" with high complexity score (35)                      |
+## |    3 | 20                   | Subroutines::ProhibitExcessComplexity - Subroutine "SCAN" with high complexity score (36)                      |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
